/**
 *
 * Copyright 2003-2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.geronimo.tomcat.valve;

import org.apache.catalina.valves.ValveBase;
import org.apache.catalina.connector.Request;
import org.apache.catalina.connector.Response;
import org.apache.geronimo.security.ContextManager;

import javax.servlet.ServletException;
import javax.security.jacc.PolicyContext;
import javax.security.auth.Subject;
import java.io.IOException;

/**
 * @version $Rev: 289136 $ $Date: 2005-09-14 20:43:39 -0600 (Wed, 14 Sep 2005) $
 */

public class PolicyContextValve extends ValveBase {

    private final String policyContextID;

    public PolicyContextValve(String policyContextID) {
        this.policyContextID = policyContextID;
    }

    public void invoke(Request request, Response response) throws IOException, ServletException {

        String oldId = PolicyContext.getContextID();

        PolicyContext.setContextID(policyContextID);
        PolicyContext.setHandlerData(request);

        // Pass this request on to the next valve in our pipeline
        try {
            getNext().invoke(request, response);
        } finally {
            PolicyContext.setContextID(oldId);
        }
    }
}
